Crate solstrale

source ·
A path tracer library

A port of the Go Solstrale library See Go Solstrale library.

Modules

  • Provides a camera used by raytracer to shoot rays into the scene
  • Basic geometric constructs
  • Objects that are hittable by rays shot by the ray tracer. Some of these hittable objects are containers for other objects Some others are used to translate or rotate other objects
  • Materials to be applied to [Hittable] objects
  • Probability density functions
  • Post processors for applying effects to the raw rendered image
  • A wrapper for the random number generator to be used by ray tracer.
  • The renderer takes a Scene as input, renders it and reports RenderProgress
  • Various small helpers used by the raytracer

Functions