GPU-accelerated rendering engine for par-term terminal emulator.
This crate provides the rendering pipeline for the terminal emulator, including:
- Cell-based GPU rendering with glyph atlas
- Sixel/iTerm2/Kitty inline graphics rendering
- Custom GLSL shader post-processing (Shadertoy/Ghostty compatible)
- Scrollbar rendering with mark overlays
- Background image rendering
- GPU utility functions
Re-exports
pub use cell_renderer::CellRenderer;pub use cell_renderer::PaneViewport;pub use custom_shader_renderer::CustomShaderRenderer;pub use graphics_renderer::GraphicsRenderer;pub use renderer::DividerRenderInfo;pub use renderer::PaneDividerSettings;pub use renderer::PaneRenderInfo;pub use renderer::PaneTitleInfo;pub use renderer::Renderer;pub use renderer::compute_visible_separator_marks;pub use scrollbar::Scrollbar;
Modules
- cell_
renderer - custom_
shader_ renderer - Custom shader renderer for post-processing effects
- gpu_
utils - Common GPU utilities for texture and sampler creation.
- graphics_
renderer - renderer
- scrollbar
Structs
- Cell
- A single terminal cell with styled content for rendering
- Scrollback
Mark - Public-facing metadata for a mark anchored to a scrollback line.
Type Aliases
- Separator
Mark - Visible command separator mark: (row, col_offset, optional_color)